==> zio-aws-ec2_2.13-5.19.17.1-sources.jar: zio/aws/ec2/model/DeleteTransitGatewayRouteRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.TransitGatewayRouteTableId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteTransitGatewayRouteRequest(
    transitGatewayRouteTableId: TransitGatewayRouteTableId,
    destinationCidrBlock: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest = {
    import DeleteTransitGatewayRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
      .builder()
      .transitGatewayRouteTableId(
        TransitGatewayRouteTableId.unwrap(
          transitGatewayRouteTableId
        ): java.lang.String
      )
      .destinationCidrBlock(destinationCidrBlock: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.ReadOnly =
    zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.wrap(buildAwsValue())
}
object DeleteTransitGatewayRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteTransitGatewayRouteRequest =
      zio.aws.ec2.model.DeleteTransitGatewayRouteRequest(
        transitGatewayRouteTableId,
        destinationCidrBlock
      )
    def transitGatewayRouteTableId: TransitGatewayRouteTableId
    def destinationCidrBlock: String
    def getTransitGatewayRouteTableId
        : ZIO[Any, Nothing, TransitGatewayRouteTableId] =
      ZIO.succeed(transitGatewayRouteTableId)
    def getDestinationCidrBlock: ZIO[Any, Nothing, String] =
      ZIO.succeed(destinationCidrBlock)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
  ) extends zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.ReadOnly {
    override val transitGatewayRouteTableId: TransitGatewayRouteTableId =
      zio.aws.ec2.model.primitives
        .TransitGatewayRouteTableId(impl.transitGatewayRouteTableId())
    override val destinationCidrBlock: String =
      impl.destinationCidrBlock(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
  ): zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/DeleteTransitGatewayRouteRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.TransitGatewayRouteTableId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteTransitGatewayRouteRequest(
    transitGatewayRouteTableId: TransitGatewayRouteTableId,
    destinationCidrBlock: String,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest = {
    import DeleteTransitGatewayRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
      .builder()
      .transitGatewayRouteTableId(
        TransitGatewayRouteTableId.unwrap(
          transitGatewayRouteTableId
        ): java.lang.String
      )
      .destinationCidrBlock(destinationCidrBlock: java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.ReadOnly =
    zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.wrap(buildAwsValue())
}
object DeleteTransitGatewayRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteTransitGatewayRouteRequest =
      zio.aws.ec2.model.DeleteTransitGatewayRouteRequest(
        transitGatewayRouteTableId,
        destinationCidrBlock,
        dryRun.map(value => value)
      )
    def transitGatewayRouteTableId: TransitGatewayRouteTableId
    def destinationCidrBlock: String
    def dryRun: Optional[Boolean]
    def getTransitGatewayRouteTableId
        : ZIO[Any, Nothing, TransitGatewayRouteTableId] =
      ZIO.succeed(transitGatewayRouteTableId)
    def getDestinationCidrBlock: ZIO[Any, Nothing, String] =
      ZIO.succeed(destinationCidrBlock)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
  ) extends zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.ReadOnly {
    override val transitGatewayRouteTableId: TransitGatewayRouteTableId =
      zio.aws.ec2.model.primitives
        .TransitGatewayRouteTableId(impl.transitGatewayRouteTableId())
    override val destinationCidrBlock: String =
      impl.destinationCidrBlock(): String
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayRouteRequest
  ): zio.aws.ec2.model.DeleteTransitGatewayRouteRequest.ReadOnly = new Wrapper(
    impl
  )
}
